==> haskell-ral-0.2.1-152-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ral
version:              0.2.1
visibility:           public
id:                   ral-0.2.1-IH7A0LtHeyNBFOwOWBErUN
key:                  ral-0.2.1-IH7A0LtHeyNBFOwOWBErUN
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    These packages don'\''t provide length-indexed variants, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  b465a9c5406de334213b7e2bfab551fd
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ral-0.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ral-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ral
hs-libraries:         HSral-0.2.1-IH7A0LtHeyNBFOwOWBErUN
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED
    adjunctions-4.4.2-ArJqvIz7v91Lf8ZLBi2rfM base-4.16.4.0
    bin-0.1.3-EDgChfhIkknFFK7bGC3vUg boring-0.2.1-Icfsg6aSH6SpFFKOquZU
    deepseq-1.4.6.1 distributive-0.6.2.1-Bx2F0eAgMfT82Es2djCngR
    fin-0.3-JQq7S1k4qmdFTezinMbV6O
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    indexed-traversable-0.1.3-1Qv6lMYD85cCoJPVws66xH
    semigroupoids-5.3.7-8VadR23YqgWJtKdu0uOLHe

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ral-0.2.1-213.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ral
version:              0.2.1
visibility:           public
id:                   ral-0.2.1-JwRM77GBUfI1bUatJTcYvn
key:                  ral-0.2.1-JwRM77GBUfI1bUatJTcYvn
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    These packages don'\''t provide length-indexed variants, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  b49f68e60b047c3dca43e63b9c963b95
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ral-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ral-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ral-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ral
hs-libraries:         HSral-0.2.1-JwRM77GBUfI1bUatJTcYvn
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
    adjunctions-4.4.3-B9agoL9wwOK5QMNprfU08j base-4.17.2.1
    bin-0.1.3-GKNBpRTD49O2neFdHDlk4a
    boring-0.2.2-HI9VvaC9JR142cnMpyID0P deepseq-1.4.8.0
    distributive-0.6.2.1-FYzr9HBqNWBC7NPu6PBGmX
    fin-0.3-1HYKTlkIrLPFIXGmjugX8n
    hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj
    indexed-traversable-0.1.4-KBBDB9eVvy75srrGe861vR
    semigroupoids-6.0.1-A8MJM4jzMu8HCltRHXZtTa

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
